<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0" exclude-result-prefixes="xs">
  <xsl:output method="xml" version="1.0" encoding="UTF-8"/>
  <xsl:template match="*">
    <xsl:element name="{local-name()}">
      <xsl:apply-templates/>
    </xsl:element>
  </xsl:template>

  <xsl:template name="rss" match="/">
    <playlist xmlns:media="http://xspf.org/ns/0/">
      <xsl:for-each select="rss">
        <xsl:attribute name="version">1</xsl:attribute>
        <trackList>
          <xsl:apply-templates name="item" select="channel/items/item"/>
        </trackList>
      </xsl:for-each>
    </playlist>
  </xsl:template>

  <xsl:template name="item" match="item">

    <!-- Find the highest video bitrate. Ignore the Source flavor. -->
    <xsl:variable name="maxNonSourceBitrate">
      <xsl:for-each select="content[@isSource='false']/@videoBitrate">
        <xsl:sort data-type="number" order="descending" />
        <xsl:if test="position()=1">
          <xsl:value-of select="." />
        </xsl:if>
      </xsl:for-each>
    </xsl:variable> 

    <track>
      <title>
        <xsl:value-of select="title"/>
      </title>
      <creator>
        <xsl:value-of select="userId"/>
      </creator>

      <!-- Output the video URL with the highest video bitrate. -->
      <location>
        <xsl:value-of select="content[@videoBitrate=$maxNonSourceBitrate]/@url" /> 
      </location>
    </track>
  </xsl:template>
</xsl:stylesheet>